@@ -1,20 +1,29 @@
 """
-pyaud.objects
-=============
+pyaud._objects
+==============
 """
+from __future__ import annotations
+
 import json as _json
-import logging as _logging
 import typing as _t
 from abc import ABC as _ABC
-from collections.abc import MutableMapping as _MutableMapping
 from pathlib import Path as _Path
 
+from lsfiles import LSFiles as _LSFiles
+from object_colors import Color as _Color
 
-class MutableMapping(_MutableMapping):  # pylint: disable=too-many-ancestors
+NAME = __name__.split(".", maxsplit=1)[0]
+
+_KT = _t.TypeVar("_KT")
+_VT = _t.TypeVar("_VT")
+_T_co = _t.TypeVar("_T_co", covariant=True)
+
+
+class MutableMapping(_t.MutableMapping[_KT, _VT]):
     """Inherit to replicate subclassing of ``dict`` objects."""
 
     def __init__(self) -> None:
-        self._dict: _t.Dict[str, _t.Any] = {}
+        self._dict: dict[_KT, _VT] = {}
 
     def __repr__(self) -> str:
         return f"<{self.__class__.__name__} {self._dict}>"
@@ -22,21 +31,21 @@ class MutableMapping(_MutableMapping):  # pylint: disable=too-many-ancestors
     def __len__(self) -> int:
         return self._dict.__len__()
 
-    def __delitem__(self, key: _t.Any) -> None:
+    def __delitem__(self, key: _KT) -> None:
         self._dict.__delitem__(key)
 
-    def __setitem__(self, key: _t.Any, value: _t.Any) -> None:
+    def __setitem__(self, key: _KT, value: _VT) -> None:
         self._dict = self._nested_update(self._dict, {key: value})
 
-    def __getitem__(self, key: _t.Any) -> _t.Any:
+    def __getitem__(self, key: _KT) -> _VT:
         return self._dict.__getitem__(key)
 
-    def __iter__(self) -> _t.Iterator:
-        return iter(self._dict)
+    def __iter__(self) -> _t.Iterator[_KT]:
+        return self._dict.__iter__()
 
     def _nested_update(
-        self, obj: _t.Dict[str, _t.Any], update: _t.Dict[str, _t.Any]
-    ) -> _t.Dict[str, _t.Any]:
+        self, obj: dict[_KT, _t.Any], update: dict[_KT, _t.Any]
+    ) -> _t.Dict[_KT, _t.Any]:
         # add to __setitem__ to ensure that no entire dict keys with
         # missing nested keys overwrite all other values
         # run recursively to cover all nested objects if value is a dict
@@ -56,6 +65,10 @@ class MutableMapping(_MutableMapping):  # pylint: disable=too-many-ancestors
         return obj
 
 
+class _Toml(MutableMapping):
+    """Base class for all ``toml`` object interaction."""
+
+
 class BasePlugin(_ABC):  # pylint: disable=too-few-public-methods
     """Base type for all plugins."""
 
@@ -68,33 +81,34 @@ class BasePlugin(_ABC):  # pylint: disable=too-few-public-methods
     #: to be valid.
     cache_all = False
 
-    @classmethod
-    def logger(cls) -> _logging.Logger:
-        """Assign an audit logger dynamically, post logging config.
-
-        :return: ``Logger`` object.
-        """
-        return _logging.getLogger(cls.__name__)
+    #: set a single cache file for plugin subclass.
+    cache_file: _t.Optional[_t.Union[str, _Path]] = None
 
 
 class JSONIO(MutableMapping):
-    """Base class JSON input/output actions.
+    """Base class JSON input/output actions."""
 
-    :param path: Path to data file.
-    """
+    def read(self, path: _Path) -> None:
+        """Read from file to object.
 
-    def __init__(self, path: _Path) -> None:
-        super().__init__()
-        self.path = path
-
-    def read(self) -> None:
-        """Read from file to object."""
-        if self.path.is_file():
+        :param path: Path to json file.
+        """
+        if path.is_file():
             try:
-                self.update(_json.loads(self.path.read_text()))
+                self.update(_json.loads(path.read_text()))
             except _json.decoder.JSONDecodeError:
                 pass
 
-    def write(self) -> None:
-        """Write data to file."""
-        self.path.write_text(_json.dumps(dict(self), separators=(",", ":")))
+    def write(self, path: _Path) -> None:
+        """Write data to file.
+
+        :param path: Path to json file.
+        """
+        path.write_text(_json.dumps(dict(self), separators=(",", ":")))
+
+
+toml = _Toml()
+colors = _Color()
+files = _LSFiles()
+
+colors.populate_colors()
