@@ -10,7 +10,7 @@ import importlib as _importlib
 import inspect as _inspect
 import os as _os
 import pkgutil as _pkgutil
-import re
+import re as _re
 import sys as _sys
 import typing as _t
 from abc import abstractmethod as _abstractmethod
@@ -19,30 +19,27 @@ from subprocess import CalledProcessError as _CalledProcessError
 
 from spall import Subprocess as _Subprocess
 
-from . import config as _config
-from . import exceptions as _exceptions
-from ._environ import environ as _environ
-from ._indexing import HashCap as _HashCap
-from ._indexing import files as _files
+from ._config import TempEnvVar as _TempEnvVar
+from ._objects import NAME as _NAME
 from ._objects import BasePlugin as _BasePlugin
 from ._objects import MutableMapping as _MutableMapping
-from ._utils import colors as _colors
+from ._objects import colors as _colors
+from ._objects import files as _files
+from ._wraps import CheckCommand as _CheckCommand
 from ._wraps import ClassDecorator as _ClassDecorator
-from ._wraps import check_command as _check_command
+from .exceptions import NameConflictError as _NameConflictError
 
 
-class _SubprocessFactory(  # pylint: disable=too-many-ancestors
-    _MutableMapping
-):
+class _SubprocessFactory(_MutableMapping):
     """Instantiate collection of ``Subprocess`` objects."""
 
-    def __init__(self, args: _t.List[str]):
+    def __init__(self, args: list[str]) -> None:
         super().__init__()
         for arg in args:
             self[arg] = _Subprocess(arg)
 
 
-class Plugin(_BasePlugin):  # pylint: disable=too-few-public-methods
+class Plugin(_BasePlugin):
     """Base class of all plugins.
 
     Raises ``TypeError`` if registered directly.
@@ -58,7 +55,6 @@ class Plugin(_BasePlugin):  # pylint: disable=too-few-public-methods
         class_decorator = _ClassDecorator(cls)
         cls.__call__ = class_decorator.not_found(cls.__call__)  # type: ignore
         cls.__call__ = class_decorator.files(cls.__call__)  # type: ignore
-        cls.__call__ = class_decorator.time(cls.__call__)  # type: ignore
         return super().__new__(cls)
 
     def __init__(self, name: str) -> None:
@@ -68,33 +64,19 @@ class Plugin(_BasePlugin):  # pylint: disable=too-few-public-methods
     def __deepcopy__(self, name: str) -> Plugin:
         return self
 
-    @staticmethod
-    def audit_error() -> _exceptions.AuditError:
-        """Raise if checks have failed.
-
-        :return: AuditError instantiated with error message.
-        """
-        return _exceptions.AuditError(" ".join(_sys.argv))
-
     @property
     def env(self) -> _t.Dict[str, str]:
-        """Return environment which will remain active for run.
-
-        :return: Dict containing any number of str keys and
-            corresponding str values.
-        """
+        """Return environment which will remain active for run."""
         return {}
 
     @property
-    def exe(self) -> _t.List[str]:
-        """List of executables to add to ``subprocess`` dict.
-
-        :return: List of str object to assign to subprocesses
-        """
+    def exe(self) -> list[str]:
+        """List of executables to add to ``subprocess`` dict."""
         return []
 
-    def __call__(self, *args: str, **kwargs: bool) -> _t.Any:
+    def __call__(self, *args: str, **kwargs: bool) -> int:
         """Enables calling of all plugin instances."""
+        return 0
 
 
 class Audit(Plugin):
@@ -127,17 +109,18 @@ class Audit(Plugin):
             notify call whether process has succeeded or failed.
         """
 
-    @_check_command
+    @_CheckCommand.files
     def __call__(self, *args: str, **kwargs: bool) -> int:
-        with _config.TempEnvVar(_os.environ, **self.env):
+        with _TempEnvVar(_os.environ, **self.env):
             try:
                 return self.audit(*args, **kwargs)
 
-            except _CalledProcessError as err:
-                raise self.audit_error() from err
+            except _CalledProcessError:
+                return 1
 
 
-class Fix(Audit):
+#: Blueprint for writing audit and fix plugins.
+class BaseFix(Audit):
     """Blueprint for writing audit and fix plugins.
 
     Audit will be called from here.
@@ -189,20 +172,118 @@ class Fix(Audit):
             notify __call__ whether process has succeeded or failed.
         """
 
-    @_check_command
-    def __call__(self, *args: str, **kwargs: bool) -> _t.Any:
-        with _config.TempEnvVar(_os.environ, **self.env):
+    def __call__(self, *args: str, **kwargs: bool) -> int:
+        with _TempEnvVar(_os.environ, **self.env):
             try:
-                return self.audit(*args, **kwargs)
+                returncode = self.audit(*args, **kwargs)
 
-            except _CalledProcessError as err:
-                if kwargs.get("fix", False):
-                    return self.fix(**kwargs)
+            except _CalledProcessError:
+                returncode = 1
 
-                raise self.audit_error() from err
+        if returncode:
+            if kwargs.get("fix", False):
+                return self.fix(**kwargs)
+
+            return 1
+
+        return returncode
 
 
-class Action(Plugin):  # pylint: disable=too-few-public-methods
+class Fix(BaseFix):
+    """Blueprint for writing audit and fix plugins for single files.
+
+    Announce file status.
+
+    :raises CalledProcessError: Will always be raised if something fails
+        that is not to do with the audit condition. Will be excepted and
+        reraised as ``AuditError`` if the audit fails and ``-f/--fix``
+        is not passed to the commandline.
+    :raises AuditError: Raised from ``CalledProcessError`` if audit
+        fails and ``-f/--fix`` flag if not passed to the commandline.
+    :return: If any error has not been raised for any reason int object
+        must be returned, from subprocess or written, to notify call
+        whether process has succeeded or failed. No value will actually
+        return from __call__ as it will be passed to the decorator.
+    """
+
+    @_abstractmethod
+    def audit(self, *args: str, **kwargs: bool) -> int:
+        """All audit logic to be written within this method.
+
+        :param args: Args that can be passed from other plugins.
+        :param kwargs: Boolean flags for subprocesses.
+        :return: If any error has not been raised for any reason int
+            object must be returned, from subprocess or written, to
+            notify __call__ whether process has succeeded or failed. If
+            non-zero exist is returned and ``-f/--fix`` has been passed
+            to the commandline run the ``fix`` method, otherwise raise
+            ``AuditError``.
+        """
+
+    @_abstractmethod
+    def fix(self, *args: str, **kwargs: bool) -> int:
+        """Run if audit fails but only if running a fix.
+
+        :param args: Args that can be passed from other plugins.
+        :param kwargs: Boolean flags for subprocesses.
+        :return: If any error has not been raised for any reason int
+            object must be returned, from subprocess or written, to
+            notify __call__ whether process has succeeded or failed.
+        """
+
+    @_CheckCommand.file
+    def __call__(self, *args: str, **kwargs: bool) -> int:
+        return super().__call__(*args, **kwargs)
+
+
+class FixAll(BaseFix):
+    """Blueprint for writing audit and fix plugins for Python files.
+
+    Announce Python file status.
+
+    :raises CalledProcessError: Will always be raised if something fails
+        that is not to do with the audit condition. Will be excepted and
+        reraised as ``AuditError`` if the audit fails and ``-f/--fix``
+        is not passed to the commandline.
+    :raises AuditError: Raised from ``CalledProcessError`` if audit
+        fails and ``-f/--fix`` flag if not passed to the commandline.
+    :return: If any error has not been raised for any reason int object
+        must be returned, from subprocess or written, to notify call
+        whether process has succeeded or failed. No value will actually
+        return from __call__ as it will be passed to the decorator.
+    """
+
+    @_abstractmethod
+    def audit(self, *args: str, **kwargs: bool) -> int:
+        """All audit logic to be written within this method.
+
+        :param args: Args that can be passed from other plugins.
+        :param kwargs: Boolean flags for subprocesses.
+        :return: If any error has not been raised for any reason int
+            object must be returned, from subprocess or written, to
+            notify __call__ whether process has succeeded or failed. If
+            non-zero exist is returned and ``-f/--fix`` has been passed
+            to the commandline run the ``fix`` method, otherwise raise
+            ``AuditError``.
+        """
+
+    @_abstractmethod
+    def fix(self, *args: str, **kwargs: bool) -> int:
+        """Run if audit fails but only if running a fix.
+
+        :param args: Args that can be passed from other plugins.
+        :param kwargs: Boolean flags for subprocesses.
+        :return: If any error has not been raised for any reason int
+            object must be returned, from subprocess or written, to
+            notify __call__ whether process has succeeded or failed.
+        """
+
+    @_CheckCommand.files
+    def __call__(self, *args: str, **kwargs: bool) -> int:
+        return super().__call__(*args, **kwargs)
+
+
+class Action(Plugin):
     """Blueprint for writing generic plugins.
 
     Called within context of defined environment variables.
@@ -217,7 +298,7 @@ class Action(Plugin):  # pylint: disable=too-few-public-methods
     """
 
     @_abstractmethod
-    def action(self, *args: str, **kwargs: bool) -> _t.Any:
+    def action(self, *args: str, **kwargs: bool) -> int:
         """All logic to be written within this method.
 
         :param args: Args that can be passed from other plugins.
@@ -225,16 +306,16 @@ class Action(Plugin):  # pylint: disable=too-few-public-methods
         :return: Any value and type can be returned.
         """
 
-    def __call__(self, *args: str, **kwargs: bool) -> _t.Any:
-        with _config.TempEnvVar(_os.environ, **self.env):
+    def __call__(self, *args: str, **kwargs: bool) -> int:
+        with _TempEnvVar(_os.environ, **self.env):
             try:
                 return self.action(*args, **kwargs)
 
-            except _CalledProcessError as err:
-                raise self.audit_error() from err
+            except _CalledProcessError:
+                return 1
 
 
-class Parametrize(Plugin):  # pylint: disable=too-few-public-methods
+class Parametrize(Plugin):
     """Define a list of strings to call multiple plugins.
 
     :raises CalledProcessError: Will always be raised if something fails
@@ -248,66 +329,19 @@ class Parametrize(Plugin):  # pylint: disable=too-few-public-methods
     """
 
     @_abstractmethod
-    def plugins(self) -> _t.List[str]:
+    def plugins(self) -> list[str]:
         """List of plugin names to run.
 
         :return: List of plugin names, as defined in ``@register``.
         """
 
-    def __call__(self, *args: str, **kwargs: bool) -> None:
+    def __call__(self, *args: str, **kwargs: bool) -> int:
         for name in self.plugins():
-            _colors.cyan.bold.print(f"\n{_environ.NAME} {name}")
+            _colors.cyan.bold.print(f"\n{_NAME} {name}")
             _plugins[name](*args, **kwargs)
 
-
-class Write(Plugin):
-    """Blueprint for writing file manipulation processes.
-
-    Announce:
-
-        - If the file did not exist and a file has been created
-        - If the file did exist and the file has not been changed
-        - If the file did exist and the file has been changed
-    """
-
-    def required(self) -> _t.Optional[_Path]:
-        """Pre-requisite for working on file (if there is one).
-
-        :return: Path object, otherwise None.
-        """
-
-    @property
-    @_abstractmethod
-    def path(self) -> _Path:
-        """Path to file, absolute or relative, that will be worked on.
-
-        :return: Returned value needs to be a Path object.
-        """
-
-    def write(self, *args: str, **kwargs: bool) -> _t.Any:
-        """All write logic to be written within this method.
-
-        :param args: Args that can be passed from other plugins.
-        :param kwargs: Boolean flags for subprocesses.
-        """
-
-    def __call__(self, *args: str, **kwargs: bool) -> None:
-        if (
-            self.required() is None  # type: ignore
-            or self.required().exists()  # type: ignore
-        ):
-            path = _Path(self.path)
-            print(f"Updating ``{path}``")
-            with _HashCap(path) as cap:
-                self.write(*args, **kwargs)
-
-            if cap.new:
-                print(f"created ``{path.name}``")
-
-            elif cap.compare:
-                print(f"``{path.name}`` is already up to date")
-            else:
-                print(f"updated ``{path.name}``")
+        # all parametrized plugins will have succeeded to make it here
+        return 0
 
 
 class FixFile(Plugin):
@@ -339,43 +373,50 @@ class FixFile(Plugin):
     """
 
     @_abstractmethod
-    def fail_condition(self) -> _t.Optional[bool]:
-        """Condition to trigger non-subprocess failure."""
+    def fail_condition(self) -> bool | None:
+        """Condition to trigger non-subprocess failure.
+
+        :return: Return True for passing condition, false for failing
+            condition, or None for no fail condition.
+        """
 
     @_abstractmethod
-    def audit(self, file: _Path, **kwargs: bool) -> None:
+    def audit(self, file: _Path, **kwargs: bool) -> int:
         """All logic written within this method for each file's audit.
 
         :param file: Individual file.
         :param kwargs: Boolean flags for subprocesses.
+        :return: Returncode.
         """
 
     @_abstractmethod
-    def fix(self, file: _Path, **kwargs: bool) -> None:
+    def fix(self, file: _Path, **kwargs: bool) -> int:
         """All logic written within this method for each file's fix.
 
         :param file: Individual file.
         :param kwargs: Boolean flags for subprocesses.
+        :return: Returncode.
         """
 
-    @_check_command
+    @_CheckCommand.files
     def __call__(self, *args: str, **kwargs: bool) -> int:
+        returncode = 0
         files = [p for p in _files if p.is_file()]
         for file in files:
-            self.audit(file, **kwargs)
+            returncode = self.audit(file, **kwargs)
             fail = self.fail_condition()
             if fail is not None and fail:
                 if kwargs.get("fix", False):
-                    self.fix(file, **kwargs)
-                else:
-                    raise self.audit_error()
+                    return self.fix(file, **kwargs)
+
+                return 1
 
         # if no error raised return 0 to decorator
-        return 0
+        return returncode
 
 
 # array of plugins
-PLUGINS = [Audit, Fix, Action, Parametrize, Write, FixFile]
+PLUGINS = [Audit, BaseFix, Fix, FixAll, Action, Parametrize, FixFile]
 
 # array of plugin names
 PLUGIN_NAMES = [t.__name__ for t in PLUGINS]
@@ -383,18 +424,21 @@ PLUGIN_NAMES = [t.__name__ for t in PLUGINS]
 # array of plugin types before instantiation
 PluginType = _t.Union[
     _t.Type[Audit],
+    _t.Type[BaseFix],
     _t.Type[Fix],
+    _t.Type[FixAll],
     _t.Type[Action],
     _t.Type[Parametrize],
-    _t.Type[Write],
     _t.Type[FixFile],
 ]
 
 # array of plugin types after instantiation
-PluginInstance = _t.Union[Audit, Fix, Action, Parametrize, Write, FixFile]
+PluginInstance = _t.Union[
+    Audit, BaseFix, Fix, FixAll, Action, Parametrize, FixFile
+]
 
 
-class Plugins(_MutableMapping):  # pylint: disable=too-many-ancestors
+class Plugins(_MutableMapping):
     """Holds registered plugins.
 
     Instantiate plugin on running __setitem__.
@@ -408,7 +452,7 @@ class Plugins(_MutableMapping):  # pylint: disable=too-many-ancestors
         # only unique names to be set in `plugins` object
         # if name is not unique raise `NameConflictError`
         if name in self:
-            raise _exceptions.NameConflictError(plugin.__name__, name)
+            raise _NameConflictError(plugin.__name__, name)
 
         mro = tuple(p.__name__ for p in _inspect.getmro(plugin))
         if not hasattr(plugin, "__bases__") or not any(
@@ -426,21 +470,28 @@ class Plugins(_MutableMapping):  # pylint: disable=too-many-ancestors
 _plugins = Plugins()
 
 
-def register(name: str) -> _t.Callable[[PluginType], PluginType]:
+def _name_plugin(plugin: PluginType) -> str:
+    parts = _re.findall("[A-Z][^A-Z]*", plugin.__name__)
+    return "-".join(parts).lower()
+
+
+def register(name: str | None = None) -> _t.Callable[[PluginType], PluginType]:
     """Register subclassed plugin to collection.
 
+    If name is not provided a name will be assigned automatically.
+
     :param name: Name to register plugin as.
     :return: Return registered plugin to call.
     """
 
-    def _register(plugin: PluginType):
-        _plugins[name] = plugin
+    def _register(plugin: PluginType) -> PluginType:
+        _plugins[name or _name_plugin(plugin)] = plugin
         return plugin
 
     return _register
 
 
-def mapping() -> _t.Dict[str, PluginInstance]:
+def mapping() -> dict[str, PluginInstance]:
     """Get dict of named keys and their corresponding plugin values.
 
     :return: Mapping of plugins and their unique names.
@@ -448,7 +499,7 @@ def mapping() -> _t.Dict[str, PluginInstance]:
     return dict(_plugins)
 
 
-def registered() -> _t.List[str]:
+def registered() -> list[str]:
     """Get list of registered plugins.
 
     :return: List of registered plugins.
@@ -456,17 +507,22 @@ def registered() -> _t.List[str]:
     return sorted(list(_plugins))
 
 
-def get(name: str) -> PluginInstance:
+def get(name: str, default: str | None = None) -> PluginInstance:
     """Get plugins by name.
 
     :param name: Unique name of plugin.
+    :param default: Default plugin if name not valid.
     :return: Callable plugin instance.
     """
-    return _plugins[name]
+    try:
+        return _plugins[name]
+    except KeyError:
+        _colors.red.print(f"no plugin named `{name}` found", file=_sys.stderr)
+        return _plugins[default]
 
 
 def load() -> None:
     """Import all package prefixed with ``pyaud[-_]``."""
     for _, name, _ in _pkgutil.iter_modules():
-        if re.match("^pyaud[-_].*$", name):
+        if _re.match("^pyaud[-_].*$", name):
             _importlib.import_module(name)
